package com.fs.ad.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.ad.domain.AdSite;

/**
 * 站点管理Service接口
 * 
 * @author fs
 * @date 2025-03-04
 */
public interface IAdSiteService extends IService<AdSite>{
    /**
     * 查询站点管理
     * 
     * @param id 站点管理主键
     * @return 站点管理
     */
    AdSite selectAdSiteById(Long id);

    /**
     * 查询站点管理列表
     * 
     * @param adSite 站点管理
     * @return 站点管理集合
     */
    List<AdSite> selectAdSiteList(AdSite adSite);

    /**
     * 新增站点管理
     * 
     * @param adSite 站点管理
     * @return 结果
     */
    int insertAdSite(AdSite adSite);

    /**
     * 修改站点管理
     * 
     * @param adSite 站点管理
     * @return 结果
     */
    int updateAdSite(AdSite adSite);

    /**
     * 批量删除站点管理
     * 
     * @param ids 需要删除的站点管理主键集合
     * @return 结果
     */
    int deleteAdSiteByIds(Long[] ids);

    /**
     * 删除站点管理信息
     * 
     * @param id 站点管理主键
     * @return 结果
     */
    int deleteAdSiteById(Long id);
}
